@@ -26,8 +26,8 @@ sub _init {
     for my $dir (@dirs) {
         $inotify->watch(
             $dir,
-            &IN_MODIFY | &IN_CREATE | &IN_DELETE | &IN_DELETE_SELF |
-              &IN_MOVE_SELF,
+            IN_MODIFY | IN_CREATE | IN_DELETE | IN_DELETE_SELF |
+              IN_MOVE | IN_MOVE_SELF,
             sub { my $e = shift; $self->_process_events($e); } );
     }
 
@@ -56,8 +56,8 @@ around '_process_events' => sub {
 
         $self->_fs_monitor->watch(
             $event->path,
-            &IN_MODIFY | &IN_CREATE | &IN_DELETE | &IN_DELETE_SELF |
-              &IN_MOVE_SELF,
+            IN_MODIFY | IN_CREATE | IN_DELETE | IN_DELETE_SELF |
+                IN_MOVE | IN_MOVE_SELF,
             sub { my $e = shift; $self->_process_events($e); } );
 
     }
@@ -77,7 +77,7 @@ AnyEvent::Filesys::Notify::Role::Linux - Use Linux::Inotify2 to watch for change
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
