@@ -3,10 +3,11 @@ package TestSupport;
 use File::Temp qw(tempdir);
 use File::Path;
 use File::Basename;
+use File::Copy qw(move);
 use autodie;
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(create_test_files delete_test_files $dir);
+our @EXPORT_OK = qw(create_test_files delete_test_files move_test_files $dir);
 
 our $dir = tempdir( CLEANUP => 1 );
 my $size = 1;
@@ -36,4 +37,14 @@ sub delete_test_files {
     }
 }
 
+sub move_test_files {
+    my (%files) = @_;
+
+    while( my ($src, $dst) = each %files ){
+        my $full_src = File::Spec->catfile( $dir, $src );
+        my $full_dst = File::Spec->catfile( $dir, $dst );
+        move $full_src, $full_dst;
+    }
+}
+
 1;
